"""
Overview:
    Meta information for hf-webdriver-manager package.
"""

#: Title of this project (should be `hf-webdriver-manager`).
__TITLE__ = "hf-webdriver-manager"

#: Version of this project.
__VERSION__ = "0.0.1"

#: Short description of the project, will be included in ``setup.py``.
__DESCRIPTION__ = 'Library provides the way to automatically manage drivers for different browsers.'

#: Author of this project.
__AUTHOR__ = "HansBug"

#: Email of the authors'.
__AUTHOR_EMAIL__ = "hansbug@buaa.edu.cn"
